%define gecko_version 1.9
%def_with direct
%def_with envvar
%def_with file
%def_with gnome
%def_with kde
%def_with wpad
%def_with networkmanager
%def_with mozjs
%def_with webkit
%def_with python
%def_with dotnet

Name: libproxy
Version: 0.3.0
Release: alt1
Summary: A library handling all the details of proxy configuration

Group: System/Libraries
License: %gpllgpl2plus
Url: http://code.google.com/p/libproxy/

Source0: http://libproxy.googlecode.com/files/libproxy-%version.tar
Patch0: %name-%version-%release.patch

BuildPreReq: rpm-build-licenses
BuildRequires: python-devel
# gnome
%{?_with_gnome:BuildRequires: libGConf2-devel libXmu-devel libX11-devel}
# kde
%{?_with_kde:BuildRequires: libXmu-devel libX11-devel}
# xulrunner
%{?_with_mozjs:BuildRequires: xulrunner-devel >= %gecko_version}
# webkit (gtk)
%{?_with_webkit:BuildRequires: libwebkit-devel}
# NetworkManager
%{?_with_networkmanager:BuildRequires: NetworkManager-devel libdbus-devel}
# dotnet
%{?_with_dotnet:BuildPreReq: mono-devel >= 2.0.0 /proc rpm-build-mono mono-mcs}

%description
libproxy offers the following features:

    * extremely small core footprint (< 35K)
    * no external dependencies within libproxy core
      (libproxy plugins may have dependencies)
    * only 3 functions in the stable external API
    * dynamic adjustment to changing network topology
    * a standard way of dealing with proxy settings across all scenarios
    * a sublime sense of joy and accomplishment

%package tools
Summary: A sample & test application to test what libproxy will reply
Group: Networking/Other
Requires: %name = %version-%release

%description tools
A simple application that will use libproxy to give the results you can expect from.
other applications. Great to debug what would happen.

%package -n python-module-%name
Summary: Python bindings for %name
Group: Development/Python
Requires: %name = %version-%release

%description -n python-module-%name
Allows for the usage of libproxy from python applications

%package gnome
Summary: Libproxy module for gnome configuration
Group: System/Libraries
Requires: %name = %version-%release

%description gnome
A module to extend libproxy with capabilities to query gnome/gconf about the proxy settings

%package kde
Summary: Libproxy module for kde configuration
Group: System/Libraries
Requires: %name = %version-%release

%description kde
A module to extend libproxy with capabilities to query KDE about proxy settings

%package mozjs
Summary: Libproxy module to support wpad/pac parsing via Mozilla JavaScript Engine
Group: System/Libraries
Requires: %name = %version-%release

%description mozjs
A module to extend libproxy with capabilities to pass addresses to a WPAD/PAC Script
to have it parse for the correct proxy. PAC requires JavaScript Engine in the back.

%package webkit
Summary: Libproxy module to support webkit
Group: System/Libraries
Requires: %name = %version-%release

%description webkit
The %name-webkit package contains the %name plugin for
WebKit.

%package networkmanager
Summary: Libproxy module for networkmanager configuration
Group: System/Libraries

%description networkmanager
A module to extend libproxy with capabilities to query NetworkManager about proxy settings

%package sharp
Summary:  Mono bindings for %name
Group: Development/Other
Requires: %name = %version-%release

%description sharp
Allows for the usage of libproxy from python applications

%package sharp-devel
Summary:  Mono bindings for %name
Group: Development/Other
Requires: %name-sharp = %version-%release

%description sharp-devel
Development files for %name-sharp-devel

%package devel
Summary: Development files for %name
Group: Development/C
Requires: %name = %version-%release

%description devel
The %name-devel package contains libraries and header files for
developing applications that use %name.

%prep
%setup -q
%patch0 -p1

%build
%__libtoolize -c -f --automake
%__aclocal
%__automake --foreign -a -c -f
%__autoconf -f

# to avoid mozilla-js bug
export mozjs_CFLAGS="`pkg-config --cflags mozilla-js` -I//usr/include/xulrunner/unstable"
%configure --includedir=%_includedir/libproxy \
	--disable-static \
	%{subst_with direct} \
	%{subst_with envvar} \
	%{subst_with file} \
	%{subst_with gnome} \
	%{subst_with kde} \
	%{subst_with wpad} \
	%{subst_with networkmanager} \
	%{subst_with mozjs} \
	%{subst_with webkit} \
	%{subst_with python} \
	%{subst_with dotnet}

%make_build

%install
%make DESTDIR=%buildroot install

%files
%_libdir/*.so.*
%dir %_libdir/%name
%dir %_libdir/%name/%version
%dir %_libdir/%name/%version/modules
%{?_with_direct:%_libdir/%name/%version/modules/config_direct.so}
%{?_with_envvar:%_libdir/%name/%version/modules/config_envvar.so}
%{?_with_file:%_libdir/%name/%version/modules/config_file.so}
%{?_with_wpad:%_libdir/%name/%version/modules/config_wpad.so}
%{?_with_wpad:%_libdir/%name/%version/modules/ignore_domain.so}
%{?_with_wpad:%_libdir/%name/%version/modules/ignore_ip.so}
%{?_with_wpad:%_libdir/%name/%version/modules/wpad_dns.so}
%{?_with_wpad:%_libdir/%name/%version/modules/wpad_dnsdevolution.so}

%doc AUTHORS README

%files tools
%_bindir/proxy

%files -n python-module-%name
%{?_with_python:%python_sitelibdir/*}

%files gnome
%{?_with_gnome:%_libdir/%name/%version/modules/config_gnome.so}

%files kde
%{?_with_kde:%_libdir/%name/%version/modules/config_kde.so}

%files mozjs
%{?_with_mozjs:%_libdir/%name/%version/modules/pacrunner_mozjs.so}

%files webkit
%{?_with_webkit:%_libdir/%name/%version/modules/pacrunner_webkit.so}

%files networkmanager
%{?_with_networkmanager:%_libdir/%name/%version/modules/network_networkmanager.so}

%files sharp
%{?_with_dotnet:%_monodir/%name-sharp}
%{?_with_dotnet:%_monogacdir/*}
%exclude %_libdir/%name/%version/libproxy-sharp.dll

%files sharp-devel
%{?_with_dotnet:%_pkgconfigdir/libproxy-sharp-1.0.pc}

%files devel
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/libproxy-1.0.pc

%changelog
* Wed Sep 23 2009 Alexey Shabalin <shaba@altlinux.ru> 0.3.0-alt1
- 0.3.0
- networkmanager package
- .Net bindings package
- update descriptions
- add versioning

* Tue May 05 2009 Alexey Shabalin <shaba@altlinux.ru> 0.2.3-alt2.r334
- svn r334
- update spec for build from git.alt

* Fri Apr 10 2009 Alexey Shabalin <shaba@altlinux.ru> 0.2.3-alt1.1
- rebuild with webkit-1.1.4

* Tue Feb 03 2009 Yuri N. Sedunov <aris@altlinux.org> 0.2.3-alt1
- adapted for Sisyphus

* Thu Jan 22 2009 kwizart < kwizart at gmail.com > - 0.2.3-8
- Merge NetworkManager module into the main libproxy package
- Main Requires the -python and -bin subpackage
 (splitted for multilibs compliance).

* Fri Oct 24 2008 kwizart < kwizart at gmail.com > - 0.2.3-7
- Disable Gnome/KDE default support via builtin modules.
 (it needs to be integrated via Gconf2/neon instead).

* Tue Oct 21 2008 kwizart < kwizart at gmail.com > - 0.2.3-6
- Disable Obsoletes.
- Requires ev instead of evr for optionnals sub-packages.

* Tue Oct 21 2008 kwizart < kwizart at gmail.com > - 0.2.3-5
- Use conditionals build.

* Mon Sep 15 2008 kwizart < kwizart at gmail.com > - 0.2.3-4
- Remove plugin- in the name of the packages

* Mon Aug  4 2008 kwizart < kwizart at gmail.com > - 0.2.3-3
- Move proxy.h to libproxy/proxy.h
  This will prevent it to be included in the default include path
- Split main to libs and util and use libproxy to install all

* Mon Aug  4 2008 kwizart < kwizart at gmail.com > - 0.2.3-2
- Rename binding-python to python
- Add Requires: gecko-libs >= %%{gecko_version}
- Fix some descriptions
- Add plugin-webkit package

* Fri Jul 11 2008 kwizart < kwizart at gmail.com > - 0.2.3-1
- Convert to Fedora spec

* Fri Jun 6 2008 - dominique-rpm@leuenberger.net
- Updated to version 0.2.3
* Wed Jun 4 2008 - dominique-rpm@leuenberger.net
- Extended spec file to build all available plugins
* Tue Jun 3 2008 - dominique-rpm@leuenberger.net
- Initial spec file for Version 0.2.2

